process_keywords

Function process_keywords 

pub fn process_keywords(
    keywords: &[u8],
    reply: &mut Reply,
) -> Result<(), FromUtf8Error>
Processes the keywords section of a reply line and fills the keyword field in the Reply struct.

Arguments

  • keywords - A byte slice containing the keywords section of the reply.
  • reply - A mutable reference to the Reply struct to be populated.