pub fn add_to_reply_keywords(
reply: &mut Reply,
key: &mut Vec<u8>,
raw_values: &mut Vec<Vec<u8>>,
has_equal: bool,
) -> Result<(), FromUtf8Error>Expand description
Adds a key and its associated values to the keywords field of a Reply struct.
Arguments
reply- The Reply struct to which the keyword will be added.key- The key as a mutable byte vector.raw_values- A mutable vector of byte arrays representing the raw values of the keyword.has_equal- A boolean indicating whether the keyword had an equal sign (i.e., had a value). If false, the keyword is treated as having a Null value.